%define build_compat32 %{?_with_compat32:1}%{!?_with_compat32:0}

Summary: A utility for getting files from remote servers (FTP, HTTP, and others).
Summary(ja): リモートサーバ(FTP,HTTPなど)からファイルを取得するためのユーティリティ
Name: curl 
Version: 7.81.0
Release: 1%{?_dist_release}
Group: internet
Vendor: Project Vine
Distribution: Vine Linux
Packager: daisuke

License: MIT
URL: https://curl.se/
Source: https://curl.se/download/%{name}-%{version}.tar.xz

# patch making libcurl multilib ready
Patch101: 0101-curl-7.73.0-multilib.patch

BuildRoot: %{_tmppath}/%{name}-%{version}-root
BuildRequires: brotli-devel
BuildRequires: gnutls-devel
BuildRequires: libidn2-devel
BuildRequires: libnghttp2-devel
BuildRequires: libpsl-devel
BuildRequires: libssh2-devel
BuildRequires: openldap-devel
BuildRequires: openssh-server
BuildRequires: openssh-clients
BuildRequires: openssl-devel
BuildRequires: pkgconfig
BuildRequires: zlib-devel

Requires: ca-certificates

%description
cURL is a tool for getting files from FTP, HTTP, Gopher, Telnet, and
Dict servers, using any of the supported protocols. cURL is designed
to work without user interaction or any kind of interactivity. cURL
offers many useful capabilities, like proxy support, user
authentication, FTP upload, HTTP post, and file transfer resume.


%package devel
Summary: Files needed for building applications with libcurl.
Group: programming
Requires: %{name} = %{version}-%{release}
Requires: openssl-devel libidn-devel zlib-devel

%description devel
cURL is a tool for getting files from FTP, HTTP, Gopher, Telnet, and
Dict servers, using any of the supported protocols. The curl-devel
package includes files needed for developing applications which can
use cURL's capabilities internally.
#'


## to build compat32 for x86_64 architecture support
%package -n compat32-%{name}
Summary: A utility for getting files from remote servers (FTP, HTTP, and others).
Summary(ja): リモートサーバ(FTP,HTTPなど)からファイルを取得するためのユーティリティ
Group: system,legacy

%description -n compat32-%{name}
cURL is a tool for getting files from FTP, HTTP, Gopher, Telnet, and
Dict servers, using any of the supported protocols. cURL is designed
to work without user interaction or any kind of interactivity. cURL
offers many useful capabilities, like proxy support, user
authentication, FTP upload, HTTP post, and file transfer resume.


%package -n compat32-%{name}-devel
Summary: Files needed for building applications with libcurl.
Group: programming,legacy

%description -n compat32-%{name}-devel
cURL is a tool for getting files from FTP, HTTP, Gopher, Telnet, and
Dict servers, using any of the supported protocols. The curl-devel
package includes files needed for developing applications which can
use cURL's capabilities internally.
#'


%debug_package


%prep
%setup -q 
%autopatch -p1

# disable test 1112 (#565305), test 1455 (occasionally fails with 'bind failed
# with errno 98: Address already in use' in Koji environment), and test 1801
# <https://github.com/bagder/curl/commit/21e82bd6#commitcomment-12226582>
# and test 1900, which is flaky and covers a deprecated feature of libcurl
# <https://github.com/curl/curl/pull/2705>
printf "1112\n1455\n1801\n1900\n" >> tests/data/DISABLED

# disable test 1319 on ppc64 (server times out)
%ifarch ppc64
echo "1319" >> tests/data/DISABLED
%endif

# temporarily disable test 582 on s390x (client times out)
%ifarch s390x
echo "582" >> tests/data/DISABLED
%endif

# adapt test 323 for updated OpenSSL
sed -e 's/^35$/35,52/' -i tests/data/test323

# use localhost6 instead of ip6-localhost in the curl test-suite
(
    # avoid glob expansion in the trace output of `bash -x`
    { set +x; } 2>/dev/null
    cmd="sed -e 's|ip6-localhost|localhost6|' -i tests/data/test[0-9]*"
    printf "+ %s\n" "$cmd" >&2
    eval "$cmd"
)

# regenerate the configure script and Makefile.in files
autoreconf -fiv


%build
%configure \
  --disable-static \
  --enable-hidden-symbols \
  --enable-ipv6 \
  --enable-ldap \
  --enable-ldaps \
  --enable-threaded-resolver \
  --with-brotli \
  --with-libidn2 \
  --with-libpsl \
  --with-libssh2 \
  --with-nghttp2 \
  --with-ssl --with-ca-bundle=%{_sysconfdir}/pki/tls/certs/ca-bundle.crt \
  %{nil}

make %{?_smp_mflags}


%install
rm -rf $RPM_BUILD_ROOT
make DESTDIR=$RPM_BUILD_ROOT install

rm -rf $RPM_BUILD_ROOT%{_libdir}/lib*.{a,la}


%clean
rm -rf $RPM_BUILD_ROOT


%files
%defattr(-,root,root)
%{!?_licensedir:%global license %%doc}
%license COPYING
%doc CHANGES README
%doc docs/BUGS.md docs/CONTRIBUTE.md docs/examples docs/FAQ docs/FEATURES.md
%doc docs/INSTALL docs/INTERNALS.md docs/MANUAL.md
%doc docs/TheArtOfHttpScripting.md docs/TODO
%{_bindir}/curl
#{_datadir}/curl/*
%{_libdir}/*.so.*
%{_mandir}/man1/*.1*

%files devel
%defattr(-,root,root)
%{_bindir}/curl-config
%{_includedir}/curl
%{_libdir}/*.so
%{_libdir}/pkgconfig/*.pc
%{_mandir}/man1/curl-config.1*
%{_mandir}/man3/*
%{_datadir}/aclocal/libcurl.m4

## to build compat32 for x86_64 architecture support
%if %{build_compat32}
%files -n compat32-%{name}
%defattr(-,root,root)
%{_libdir}/*.so.*

%files -n compat32-%{name}-devel
%defattr(-,root,root)
%{_libdir}/*.so
%endif


%changelog
* Wed Jan 05 2022 Tomohiro "Tomo-p" KATO <tomop@teamgedoh.net> 7.81.0-1
- new upstream release.

* Wed Nov 10 2021 Tomohiro "Tomo-p" KATO <tomop@teamgedoh.net> 7.80.0-1
- new upstream release.

* Sat Oct 02 2021 Tomohiro "Tomo-p" KATO <tomop@teamgedoh.net> 7.79.1-1
- new upstream release.

* Thu Jul 29 2021 Tomohiro "Tomo-p" KATO <tomop@teamgedoh.net> 7.78.0-1
- new upstream release.
- dropped Patch102 and 105.

* Wed Jun 23 2021 Tomohiro "Tomo-p" KATO <tomop@teamgedoh.net> 7.77.0-1
- new upstream release.

* Wed Apr 21 2021 Tomohiro "Tomo-p" KATO <tomop@teamgedoh.net> 7.76.1-1
- new upstream release.

* Wed Apr 07 2021 Tomohiro "Tomo-p" KATO <tomop@teamgedoh.net> 7.76.0-1
- new upstream release.
- dropped ldconfig scriptlets.
- dropped Patch2, 102-104.

* Sat Feb 20 2021 Tomohiro "Tomo-p" KATO <tomop@teamgedoh.net> 7.75.0-1
- new upstream release.

* Wed Dec 16 2020 Tomohiro "Tomo-p" KATO <tomop@teamgedoh.net> 7.74.0-1
- new upstream release.

* Tue Nov 03 2020 Tomohiro "Tomo-p" KATO <tomop@teamgedoh.net> 7.73.0-1
- new upstream release.
- updated Patch0101 and Patch0104.

* Fri Jul 10 2020 Tomohiro "Tomo-p" KATO <tomop@teamgedoh.net> 7.71.1-1
- new upstream release.

* Tue Jun 09 2020 Tomohiro "Tomo-p" KATO <tomop@teamgedoh.net> 7.70.0-1
- new upstream release.

* Sun Feb 16 2020 Tomohiro "Tomo-p" KATO <tomop@teamgedoh.net> 7.68.0-1
- new upstream release.

* Sat Sep 21 2019 Tomohiro "Tomo-p" KATO <tomop@teamgedoh.net> 7.66.0-1
- new upstream release.
- dropped Patch1 and 2: fixed in upstream.

* Thu Aug 29 2019 Tomohiro "Tomo-p" KATO <tomop@teamgedoh.net> 7.65.3-1
- new upstream release.
- updated patches.
- imported Patch1, 103 and 105 from rawhide.

* Sat Nov 03 2018 Tomohiro "Tomo-p" KATO <tomop@teamgedoh.net> 7.62.0-1
- new upstream release.
- imported patches from rawhide.

* Fri Apr 13 2018 Tomohiro "Tomo-p" KATO <tomop@teamgedoh.net> 7.59.0-1
- new upstream release.
- imported Patch1 and 103 from rawhide.

* Wed Feb  7 2018 Satoshi IWAMOTO <satoshi.iwamoto@nifty.ne.jp> 7.58.0-1
- new upstream release with security fix
- update patch101

* Thu Jan 04 2018 Tomohiro "Tomo-p" KATO <tomop@teamgedoh.net> 7.57.0-1
- new upstream release.
- updated Patch101-104.
- dropped Patch107.

* Mon May  1 2017 Tomohiro "Tomo-p" KATO <tomop@teamgedoh.net> 7.54.0-1
- new upstream release.

* Thu Mar 16 2017 Tomohiro "Tomo-p" KATO <tomop@teamgedoh.net> 7.53.1-1
- new upstream release.

* Wed Dec 21 2016 Tomohiro "Tomo-p" KATO <tomop@teamgedoh.net> 7.51.0-1
- new upstream release.

* Fri Jul 29 2016 Tomohiro "Tomo-p" KATO <tomop@teamgedoh.net> 7.50.0-1
- new upstream release.
- disabled HTTP/2 on Vine6.

* Sat Jul 16 2016 Tomohiro "Tomo-p" KATO <tomop@teamgedoh.net> 7.49.1-2
- added HTTP/2 support.

* Tue Jun 28 2016 Tomohiro "Tomo-p" KATO <tomop@teamgedoh.net> 7.49.1-1
- new upstream release with security fix.

* Sat May 21 2016 Tomohiro "Tomo-p" KATO <tomop@teamgedoh.net> 7.49.0-1
- new upstream release.

* Sat Mar 12 2016 Satoshi IWAMOTO <satoshi.iwamoto@nifty.ne.jp> 7.47.1-1
- new upstream release
- built with openssl 1.0.2g

* Fri Jun 26 2015 Tomohiro "Tomo-p" KATO <tomop@teamgedoh.net> 7.43.0-1
- new upstream release with security fix .
- removed Patch108 (fixed in upstream).

* Sun Nov  9 2014 Satoshi IWAMOTO <satoshi.iwamoto@nifty.ne.jp> 7.39.0-1
- new upstream release with security fix 

* Sun Jan 19 2014 Daisuke SUZUKI <daisuke@linux.or.jp> 7.34.0-1
- new upstream release
- add libcurl.m4 to -devel package

* Wed Sep 25 2013 Daisuke SUZUKI <daisuke@linux.or.jp> 7.32.0-1
- new upstream release
- import upstream/fedora patches
- disable libssh2 on Vine Linux 6

* Thu Nov 29 2012 Daisuke SUZUKI <daisuke@linux.or.jp> 7.28.1-1
- new upstream reelase

* Sun Oct 28 2012 Daisuke SUZUKI <daisuke@linux.or.jp> 7.28.0-1
- update to 7.28.0
- add configure options
  - --enable-ssh2, --enable-threaded-resolver, --enable-ldaps
- add BR: libssh2-devel, openssh-clients, openssh-server, pkgconfig
  
- use ca-certificates package
  - --with-ca-bundle=%{_sysconfdir}/pki/tls/certs/ca-bundle.crt
  - R: ca-certificates

* Tue Feb 21 2012 NAKAMURA Kenta <kenta@vinelinux.org> 7.24.0-1
- new upstream release

* Sun Jul  3 2011 Satoshi IWAMOTO <satoshi.iwamoto@nifty.ne.jp> 7.20.1-4
- add patch100 for fix CVE-2011-2192 (gssapi)
- add Vendor/Distri tags

* Tue Jan 11 2011 Yoji TOYODA <bsyamato@sea.plala.or.jp> 7.20.1-3
- rebuild with openssl-1.0.0c

* Sun Sep 26 2010 Shu KONNO <owa@bg.wakwak.com> 7.20.1-2
- rebuilt with rpm-4.8.1 for pkg-config

* Sun Apr 25 2010 Ryoichi INAGAKI <ryo1@bc.wakwak.com> 7.20.1-1
- new upstream release

* Thu Aug 13 2009 Daisuke SUZUKI <daisuke@linux.or.jp> 7.19.6-1
- new upstream release with security fix

* Sat Jul 04 2009 Munehiro Yamamoto <munepi@cg8.so-net.ne.jp> 7.19.5-2
- added compat32 subpackages

* Tue May 19 2009 Satoshi IWAMOTO <satoshi.iwamoto@nifty.ne.jp> 7.19.5-1
- new upstream release
- use "_smp_mflags" flag

* Sat Apr 04 2009 Daisuke SUZUKI <daisuke@linux.or.jp> 7.19.4-2
- rebuild with openldap-2.4.11
- add BR: openldap-devel
- remove static library

* Sat Mar 07 2009 Satoshi IWAMOTO <satoshi.iwamoto@nifty.ne.jp> 7.19.4-1
- new upstream release with security fix (CVE-2009-0037)

* Sun Jul  6 2008 Ryoichi INAGAKI <ryo1@bc.wakwak.com> 7.18.2-1
- new upstream release

* Tue Apr 15 2008 Ryoichi INAGAKI <ryo1@bc.wakwak.com> 7.18.1-1vl5
- new upstream release

* Wed Mar 26 2008 Ryoichi INAGAKI <ryo1@bc.wakwak.com> 7.18.0-1vl5
- new upstream release

* Thu Dec 13 2007 Ryoichi INAGAKI <ryo1@bc.wakwak.com> 7.17.1-0vl1
- new upstream release

* Wed Jul 11 2007 AKIYAMA Kazuhito <akiyama@yb3.so-net.ne.jp> 7.16.4-0vl1
- new upstream release

* Sat May 19 2007 Ryoichi INAGAKI <ryo1@bc.wakwak.com> 7.16.2-0vl2
- rebuilt with openssl-0.9.8e

* Sun May 13 2007 AKIYAMA Kazuhito <akiyama@yb3.so-net.ne.jp> 7.16.2-0vl1
- new upstream release

* Wed Mar 22 2006 AKIYAMA Kazuhito <akiyama@yb3.so-net.ne.jp> 7.15.3-0vl1
- new upstream release

* Tue Feb 28 2006 AKIYAMA Kazuhito <akiyama@yb3.so-net.ne.jp> 7.15.2-0vl1
- new upstream release
- add pkgconfig file to devel package

* Wed Dec  7 2005 AKIYAMA Kazuhito <akiyama@yb3.so-net.ne.jp> 7.15.1-0vl1
- new upstream release

* Tue Oct 18 2005 AKIYAMA Kazuhito <akiyama@yb3.so-net.ne.jp> 7.15.0-0vl1
- new upstream release

* Fri Sep  2 2005 AKIYAMA Kazuhito <akiyama@yb3.so-net.ne.jp> 7.14.1-0vl1
- new upstream release

* Mon Feb 14 2005 Satoshi MACHINO <machino@vinelinux.org> 7.13.0-0vl3
- added libidn, zlib in Requires
- added libidn-devel, zlib-devel in BuildPrereq
- added zlib-devel in curl-devel's Requires

* Sun Feb 13 2005 Satoshi MACHINO <machino@vinelinux.org> 7.13.0-0vl2
- added openssl-devel, libidn-devel in curl-devel's Requires

* Sun Feb 13 2005 Satoshi MACHINO <machino@vinelinux.org> 7.13.0-0vl1
- new upstream release

* Tue Mar 30 2004 Ryoichi INAGAKI <ryo1@bc.wakwak.com> 7.11.1-0vl1
- new upstream release
- rebuild with openssl-0.9.7d

* Sun Sep 14 2003 HOTTA Michihide <hotta@net-newbie.com> 7.10.7-0vl1
- upstream release

* Sat Feb 15 2003 AKIYAMA Kazuhito <akiyama@yb3.so-net.ne.jp> 7.10.3-0vl2
- add %%{_datadir}/curl/* to %%files section

* Sun Jan 19 2003 AKIYAMA Kazuhito <akiyama@yb3.so-net.ne.jp> 7.10.3-0vl1
- source upgrade

* Wed Jul 24 2002 AKIYAMA Kazuhito <akiyama@yb3.so-net.ne.jp> 7.9.8-0vl1
- source upgrade
- add PreReq: ldconfig
- add %%{_libdir}/*.la to %%files devel section

* Sat Jan 12 2002 AKIYAMA Kazuhito <akiyama@karen.servepics.com> 7.9.2-2vl1
- build for VineSeed
- add Requires: openssl

* Wed Jan 09 2002 Tim Powers <timp@redhat.com>
- automated rebuild

* Wed Jan  9 2002 Trond Eivind Glomsr.A綬d <teg@redhat.com> 7.9.2-1
- 7.9.2

* Fri Aug 17 2001 Nalin Dahyabhai <nalin@redhat.com>
- include curl-config in curl-devel
- update to 7.8 to fix memory leak and strlcat() symbol pollution from libcurl

* Wed Jul 18 2001 Crutcher Dunnavant <crutcher@redhat.com>
- added openssl-devel build req

* Mon May 21 2001 Tim Powers <timp@redhat.com>
- built for the distro

* Tue Apr 24 2001 Jeff Johnson <jbj@redhat.com>
- upgrade to curl-7.7.2.
- enable IPv6.

* Fri Mar  2 2001 Tim Powers <timp@redhat.com>
- rebuilt against openssl-0.9.6-1

* Thu Jan  4 2001 Tim Powers <timp@redhat.com>
- fixed mising ldconfigs
- updated to 7.5.2, bug fixes

* Mon Dec 11 2000 Tim Powers <timp@redhat.com>
- updated to 7.5.1

* Mon Nov  6 2000 Tim Powers <timp@redhat.com>
- update to 7.4.1 to fix bug #20337, problems with curl -c
- not using patch anymore, it's included in the new source. Keeping
  for reference

* Fri Oct 20 2000 Nalin Dahyabhai <nalin@redhat.com>
- fix bogus req in -devel package

* Fri Oct 20 2000 Tim Powers <timp@redhat.com> 
- devel package needed defattr so that root owns the files

* Mon Oct 16 2000 Nalin Dahyabhai <nalin@redhat.com>
- update to 7.3
- apply vsprintf/vsnprintf patch from Colin Phipps via Debian

* Mon Aug 21 2000 Nalin Dahyabhai <nalin@redhat.com>
- enable SSL support
- fix packager tag
- move buildroot to %%{_tmppath}

* Tue Aug 1 2000 Tim Powers <timp@redhat.com>
- fixed vendor tag for bug #15028

* Mon Jul 24 2000 Prospector <prospector@redhat.com>
- rebuilt

* Tue Jul 11 2000 Tim Powers <timp@redhat.com>
- workaround alpha build problems with optimizations

* Mon Jul 10 2000 Tim Powers <timp@redhat.com>
- rebuilt

* Mon Jun 5 2000 Tim Powers <timp@redhat.com>
- put man pages in correct place
- use %%makeinstall

* Mon Apr 24 2000 Tim Powers <timp@redhat.com>
- updated to 6.5.2

* Wed Nov 3 1999 Tim Powers <timp@redhat.com>
- updated sources to 6.2
- gzip man page

* Mon Aug 30 1999 Tim Powers <timp@redhat.com>
- changed group

* Thu Aug 26 1999 Tim Powers <timp@redhat.com>
- changelog started
- general cleanups, changed prefix to /usr, added manpage to files section
- including in Powertools
